Updates
~~~~~~~
Scopus is a living database with changes happning constantly.  These are not just additions of new items (Articles, Books, ...) as they are published or updated citation counts, but also backfills of existing sources and corrections.  Corrections include changes of titles, names or abstracts, mergers of duplicate authors, affiliations or even research items.  Mergers affect multiple entities: For example mergers of authors affect both the authors and the articles of the duplicate.

For these reasons update your cached files regularly.  Implement cross-checks to verify that an abstract is also listed as publication in the author profile.

Corrections in the Scopus database can be reported `here <https://service.elsevier.com/app/contact/supporthub/scopuscontent/>`_.
